@@ -57,8 +57,6 @@ body_add_img <- function( x, src, style = NULL, width, height, pos = "after" ){
 
   ext_img <- external_img(new_src, width = width, height = height)
   xml_elt <- runs_to_p_wml(ext_img, add_ns = TRUE, style_id = style_id)
-  x <- docx_reference_img(x, new_src)
-  xml_elt <- wml_link_images( x, xml_elt )
 
   body_add_xml(x = x, str = xml_elt, pos = pos)
 }
@@ -268,22 +266,11 @@ body_add_fpar <- function( x, value, style = NULL, pos = "after" ){
   })
   img_src <- unique(img_src[!is.na(img_src)])
 
-  hrefs <- sapply(value$chunks, function(x){
-    if( inherits(x, "hyperlink_ftext"))
-      as.character(x$href)
-    else NA_character_
-  })
-  hrefs <- unique(hrefs[!is.na(hrefs)])
-
   if( !is.null(style) ){
     style_id <- get_style_id(data = x$styles, style=style, type = "paragraph")
   } else style_id <- NULL
 
   xml_elt <- to_wml(value, add_ns = TRUE, style_id = style_id)
-  x <- docx_reference_img(x, img_src)
-  xml_elt <- wml_link_images( x, xml_elt )
-  x <- docx_reference_hyperlink(x, hrefs)
-  xml_elt <- wml_link_hyperlink( x, xml_elt )
 
   body_add_xml(x = x, str = xml_elt, pos = pos)
 }
@@ -644,22 +631,12 @@ body_add.fpar <- function( x, value, style = NULL, ... ){
     else NA_character_
   })
   img_src <- unique(img_src[!is.na(img_src)])
-  hrefs <- sapply(value$chunks, function(x){
-    if( inherits(x, "hyperlink_ftext"))
-      as.character(x$href)
-    else NA_character_
-  })
-  hrefs <- unique(hrefs[!is.na(hrefs)])
 
   if( !is.null(style) ){
     style_id <- get_style_id(data = x$styles, style=style, type = "paragraph")
   } else style_id <- NULL
 
   xml_elt <- to_wml(value, add_ns = TRUE, style_id = style_id)
-  x <- docx_reference_img(x, img_src)
-  xml_elt <- wml_link_images( x, xml_elt )
-  x <- docx_reference_hyperlink(x, hrefs)
-  xml_elt <- wml_link_hyperlink( x, xml_elt )
 
   body_add_xml2(x = x, str = xml_elt)
 }
@@ -750,9 +727,6 @@ body_add.external_img <- function( x, value, style = "Normal", ... ){
                     to_wml(value, add_ns = FALSE),
                     "</w:p>")
 
-  x <- docx_reference_img(x, new_src)
-  xml_elt <- wml_link_images( x, xml_elt )
-
   body_add_xml2(x = x, str = xml_elt)
 }
 
