@@ -25,9 +25,8 @@ get_ph_loc <- function(x, layout, master, type, position_right, position_top, id
   if( nrow(props) > 1) {
     warning("more than a row have been selected")
   }
-
-  props <- props[, c("offx", "offy", "cx", "cy", "ph_label", "ph", "type")]
-  names(props) <- c("left", "top", "width", "height", "ph_label", "ph", "type")
+  props <- props[, c("offx", "offy", "cx", "cy", "ph_label", "ph", "type", "rotation")]
+  names(props) <- c("left", "top", "width", "height", "ph_label", "ph", "type", "rotation")
   as_ph_location(props)
 }
 
@@ -36,7 +35,7 @@ as_ph_location <- function(x, ...){
     stop("x should be a data.frame")
   }
   ref_names <- c( "width", "height", "left", "top",
-                  "ph_label", "ph", "type")
+                  "ph_label", "ph", "type", "rotation")
   if (!all(is.element(ref_names, names(x) ))) {
     stop("missing column values:", paste0(setdiff(ref_names, names(x)), collapse = ","))
   }
@@ -214,8 +213,10 @@ fortify_location.location_type <- function( x, doc, ...){
   slide <- doc$slide$get_slide(doc$cursor)
   xfrm <- slide$get_xfrm()
   args <- list(...)
+
   layout <- ifelse(is.null(args$layout), unique( xfrm$name ), args$layout)
   master <- ifelse(is.null(args$master), unique( xfrm$master_name ), args$master)
+
   out <- get_ph_loc(doc, layout = layout, master = master,
              type = x$type, position_right = x$position_right,
              position_top = x$position_top, id = x$id)
@@ -261,11 +262,12 @@ fortify_location.location_label <- function( x, doc, ...){
   }
 
   if( nrow(props) > 1) {
-    warning("more than a row have been selected")
+    stop("Placeholder ", shQuote(x$ph_label),
+         " in the slide layout is duplicated. It needs to be unique.")
   }
 
-  props <- props[, c("offx", "offy", "cx", "cy", "ph_label", "ph", "type")]
-  names(props) <- c("left", "top", "width", "height", "ph_label", "ph", "type")
+  props <- props[, c("offx", "offy", "cx", "cy", "ph_label", "ph", "type", "rotation")]
+  names(props) <- c("left", "top", "width", "height", "ph_label", "ph", "type", "rotation")
   row.names(props) <- NULL
   out <- as_ph_location(props)
   if( !is.null(x$label) )
@@ -303,6 +305,7 @@ fortify_location.location_fullsize <- function( x, doc, ...){
     layout_data$ph_label <- x$label
   layout_data$ph <- NA_character_
   layout_data$type <- "body"
+  layout_data$rotation <- 0L
 
   as_ph_location(as.data.frame(layout_data, stringsAsFactors = FALSE))
 }
